import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
from scipy.stats import sem

# Load the CSV file
df = pd.read_csv("../../data/dictator/dictator_temperature.csv")

# Group data by Model and Temperature, computing the mean and standard error
summary = df.groupby(["Model", "Temperature"]).agg(
    mean_my_share=("My Share", "mean"),
    sem_my_share=("My Share", sem)  # Standard error of the mean
).reset_index()

# Define a custom color palette for the models
color_palette = {
    'gpt-4.5-preview-2025-02-27': '#7abaff',  # BlueEscape
    'llama3': '#32a68c',  # vertAvenir
    'mistral-small': '#ff6941',  # orangeChaleureux
    'deepseek-r1': '#5862ed'  # indigoInclusif
}

# Plot settings
plt.figure(figsize=(10, 6))

# Iterate through models to plot each one
for i, model in enumerate(summary["Model"].unique()):
    subset = summary[summary["Model"] == model]
    # Plot the mean My Share with custom color
    plt.plot(subset["Temperature"], subset["mean_my_share"], marker="o", label=model, color=color_palette[model])

    # Fill the confidence interval with custom color
    plt.fill_between(
        subset["Temperature"],
        subset["mean_my_share"] - 1.96 * subset["sem_my_share"],  # Lower bound (95% CI)
        subset["mean_my_share"] + 1.96 * subset["sem_my_share"],  # Upper bound (95% CI)
        alpha=0.2,
        color=color_palette[model]  # Use model-specific color for CI fill
    )

# Set the y-axis limits between 0 and 100
plt.xlim(0, 1)
# Labels and title
plt.xlabel("Temperature")
plt.ylabel("My Share")
plt.title("My Share vs Temperature with Confidence Interval")
plt.legend(title="Model")
plt.ylim(20, 70)  # Ensure the y-axis is between 0 and 100
plt.grid(True)

# Save the figure as an SVG file
plt.savefig('../../figures/dictator/dictator_temperature.svg', format='svg')